* MEDEG STATA COURSE 2018 
* INSTRUCTOR: Tomas Martinez
*
* TENTH LECTURE:
*				- How to organize a do-file?
*				- Example of a project
*				
* ============================================================================ *

* ============================================================================ *
* 					THIS DO FILE GENERATES VARIABLES AND SELECT THE SAMPLE			
* ============================================================================ *

clear
use 01_alldata.dta

***** Generate and recode new variables

* Top code var
replace incwage=. if incwage>=9999998 // top coded
replace inctot=. if inctot>=9999998 // top coded
replace uhrsworkly=. if uhrsworkly>=998 

* Recode variables
gen rwage=incwage*cpi99 
label var rwage "Real Wage"

gen rinc=inctot*cpi99 
label var rinc "Real Income"

gen lwage=log(rwage)
label var lwage "Log Real Wage"

gen married=(marst==1 | marst==2) 
label var married "Married"

gen employed=(empstat==10 | empstat==12)  if empstat!=0 & empstat!=1 
label var employed "Employed"

gen lbf = (empstat>=10 | empstat<=29 ) // labor force participation
label var lbf "Labor force participation"

gen age2=age^2
label var age2 "Age squared"

gen fem = (sex==2) // labor force participation
label var fem "Female"
label define fem 0 "Male" 1 "Female"
label values fem fem

recode educ99 (0/9=1) (10=2) (11/14=3) (15/max=4), gen(educ)
label var educ "Education"
label define educ 1 "Less than HS" 2 "High School" 3 "Some College" 4 "College Grad"
label values educ educ

recode race (100=1) (200=2) (651=3) (652/max=4) (300=4), gen(race2)
label define race2 1 "White" 2 "Black" 3 "Asian" 4 "Other"
label values race2 race2

*** Create new variables

* Family var
bysort year serial: gen n_hh=_N // number of people in the hh
label var n_hh "# HH people"

g temp=age<11
g temp1=age<5
bysort year serial: egen nchild_10=sum(temp) // number of children <11
label var nchild_10 "# Children 10 years or less"
bysort year serial: egen nchild_4=sum(temp1) // number of children <5
label var nchild_4 "# Children 4 years or less"
drop temp temp1

* Total hh income
bysort year serial: egen hh_inc=sum(rinc)
label var hh_inc "HH income"

gen hh_incpc=hh_inc/n_hh
label var hh_incpc "HH income per capita"

* recode the wage of wife / husband to be in the same observation
gen temp1=rwage if relate==101
bysort year serial: egen whead=max(temp1) 
label var whead "Wage of head"

gen temp2=rwage if relate==201 | relate==1114
bysort year serial: egen wspouse = max(temp2) 
label var wspouse "Wage of spouse"
drop temp1 temp2

* drop useless variables (make your data smaller
drop incwage inctot marst empstat sex educ99 race occ month asecflag cpi99

***** Sample Selection
keep if age>=18 & age<=65

***** Save your data
save 02_sample.dta, replace
